@@ -9,19 +9,23 @@ use Machine::State::Transition;
 
 use parent 'Exporter::Tiny';
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 our %CONFIGS;
 our @EXPORT_OK   = qw(at_state in_state topic);
 our %EXPORT_TAGS = (dsl => \@EXPORT_OK);
 
-sub BEGIN {
+sub import {
+    my $class  = shift;
+    my $target = caller;
+
     no strict 'refs';
     no warnings 'redefine';
-    my $target = caller;
     push @{"${target}::ISA"}, 'Machine::State';
     my $constructor = $target->can('new');
+
     *{"${target}::new"} = sub { $constructor->(BUILDMACHINE(@_)) };
+    $class->next::method({into => $target}, @_);
 }
 
 sub topic {
@@ -51,7 +55,7 @@ sub BUILDMACHINE {
     my $init  = $config->get('at_state')->get(0)->first;
     my $root  = Machine::State::State->new(name => $init);
     my $topic = $config->get('topic')->get(0)->first;
-    my $nodes = $config->get('in_state');
+    my $nodes = [$config->get('at_state')->list, $config->get('in_state')->list];
 
     my %register = ($init => $root);
 
@@ -122,7 +126,7 @@ Machine::State::Simple - Simple State Machine DSL
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
